@@ -122,3 +122,12 @@ class CardResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
+    def enable_card_to_card_payment(self, request: EnableCardToCardPaymentsRequest) ->\
+            Union[UnitResponse[CardToCardPaymentDTO], UnitError]:
+        payload = request.to_json_api()
+        response = super().patch(f"{self.resource}/{request.card_id}", payload)
+        if super().is_20x(response.status_code):
+            data = response.json().get("data")
+            return UnitResponse[CardToCardPaymentDTO](DtoDecoder.decode(data), None)
+        else:
+            return UnitError.from_json_api(response.json())
