@@ -81,7 +81,7 @@ class ApproveAuthorizationRequest(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class DeclineAuthorizationRequest(object):
@@ -102,4 +102,4 @@ class DeclineAuthorizationRequest(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
