@@ -177,7 +177,7 @@ class CreateIndividualDebitCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class CreateBusinessCard(object):
@@ -252,7 +252,7 @@ class CreateBusinessCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class CreateBusinessDebitCard(CreateBusinessCard):
@@ -290,7 +290,7 @@ class CreateIndividualVirtualDebitCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class CreateBusinessVirtualCard(object):
@@ -347,7 +347,7 @@ class CreateBusinessVirtualCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class CreateBusinessVirtualDebitCard(CreateBusinessVirtualCard):
@@ -392,7 +392,7 @@ class PatchIndividualDebitCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class PatchBusinessCard(object):
@@ -440,7 +440,7 @@ class PatchBusinessCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class PatchBusinessDebitCard(PatchBusinessCard):
@@ -471,7 +471,7 @@ class PatchIndividualVirtualDebitCard(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class PatchBusinessVirtualCard(object):
@@ -542,7 +542,7 @@ class ReplaceCardRequest(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 PinStatus = Literal["Set", "NotSet"]
@@ -619,7 +619,7 @@ class GetMobileWalletPayloadRequest(UnitRequest):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class MobileWalletPayloadDTO(object):
@@ -631,3 +631,38 @@ class MobileWalletPayloadDTO(object):
     def from_json_api(_id, _type, attributes, relationships):
         return MobileWalletPayloadDTO(attributes["payload"])
 
+
+class EnableCardToCardPaymentsRequest(UnitRequest):
+    def __init__(self, card_id: str, astra_token: str, idempotency_key: Optional[str] = None):
+        self.card_id = card_id
+        self.astra_token = astra_token
+        self.idempotency_key = idempotency_key
+
+    def to_json_api(self) -> Dict:
+        payload = {
+            "data": {
+                "type": "astra",
+                "attributes": {
+                    "token": self.astra_token
+                }
+            }
+        }
+
+        if self.idempotency_key:
+            payload["data"]["attributes"]["idempotencyKey"] = self.idempotency_key
+
+        return payload
+
+    def __repr__(self):
+        return json.dumps(self.to_json_api())
+
+
+class CardToCardPaymentDTO(object):
+    def __init__(self, _type: str, _id: str, astra_card_id: str):
+        self._type = _type
+        self._id = _id
+        self.astra_card_id = astra_card_id
+
+    @staticmethod
+    def from_json_api(_id, _type, attributes, relationships):
+        return CardToCardPaymentDTO(_id, _type, attributes["astraCardId"])
