@@ -48,7 +48,7 @@ class PatchReceivedPaymentRequest(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class ListReceivedPaymentParams(UnitParams):
